###Has an invasive lizard lost its antipredator behaviours 
###following 40 years of isolation from snake predators?

#Statistical Analyses

####i. import, transform data

#Experiment 1: activity-exploration test
####1.1. Linear model of activity-exploration score by population

#Experiment 2: Antipredator behaviour
####2.1. linear mixed-effects models to analyse basking behaviour
####2.2. Cox proportional hazards tests for latency to emerge from shelter
####2.3. Cox proportional hazards tests for foraging speed (latency to catch cricket)

#Experiment 3: simultaneous predator threats
####3.1. Cox proportional hazards tests to measure latency to enter the shelter
####3.2. binomial glm to measure whether the safe or predator-scented shelter was chosen

###########################################
#i. import, transform and scale data

#load required packages
require(tidyverse)
library(lme4)
library(car)
library(survival)
library(coxme)
library(survminer)
library(dplyr)

#import data for for experiment 1 and 2
df <- read.csv("~/Library/Mobile Documents/com~apple~CloudDocs/Data/predator cues/Experiment1and2.csv")
df$logactivity<-log(df$activity)
#scale continuous variables
df$activity<-scale(df$activity)
df$spropbask<-scale(df$propbask)
df$rankactivity<-rank(df$activity)
#subdivide by population
nbay<-(df[df$pop=='N_bay',])
coffs<-(df[df$pop=='Coffs',])

#for experiment 3
dfs <- read.csv("~/Library/Mobile Documents/com~apple~CloudDocs/Data/predator cues/Experiment3.csv")
dfs$rankactivity<-rank(dfs$activity)
dfs$population<-as.factor((dfs$population))
dfs$skink<-as.factor((dfs$skink))
dfs$initial.condition<-as.factor((dfs$initial.condition))
dfs$decision<-as.numeric(dfs$decision)

#Experiment 1: activity-exploration test
###########################################
#1.1. Linear model of activity-exploration score by population
pop.lm<-lm(activity~pop, df)
Anova(pop.lm)
summary(pop.lm)

#Experiment 2: Antipredator behaviour
############################################
#2.1 linear mixed-effects models to analyse basking behaviour
##basking time global
shapiro.test((df$spropbask))
shapiro.test(df$rankpbask) #doesn't help so use untransformed
bask.lme<-lmer(propbask~treatment*pop*
                 rankactivity+svl+firstcue_spider+(1|skink:pop), data=df)
bask.lme2<-lmer(propbask~treatment+pop+
                  rankactivity+svl+firstcue_spider+(1|skink:pop), data=df)
bask.lme3<-lmer(propbask~treatment+pop*
                  rankactivity+svl+firstcue_spider+(1|skink:pop), data=df)
bask.lme4<-lmer(propbask~treatment+pop:
                  rankactivity+svl+firstcue_spider+(1|skink:pop), data=df)
anova(bask.lme, bask.lme2, type=2) #without interaction is better fit, but interaction trends towards significance so keep
summary(bask.lme)#
#next: calculate p values with likelihood ratio tests
anova(bask.lme, bask.lme3, type=2) #lme4 is best fit
anova(bask.lme, bask.lme4, type=2)
anova(bask.lme2, bask.lme3, type=2)
Anova(bask.lme4) #interaction between pop and rank
summary(bask.lme4)
fixed.effects(bask.lme4)

#dividing by population
c.bask.lme<-lmer(propbask~treatment*
                   rankactivity+svl+firstcue_spider+(1|skink:pop), data=coffs)
c.bask.lme2<-lmer(propbask~treatment+
                    rankactivity+svl+firstcue_spider+(1|skink:pop), data=coffs)
anova(c.bask.lme, c.bask.lme2)
Anova(c.bask.lme2)
summary(c.bask.lme2)
n.bask.lme<-lmer(propbask~treatment*
                   rankactivity+svl+firstcue_spider+(1|skink), data=nbay)
n.bask.lme2<-lmer(propbask~treatment+
                    rankactivity+svl+firstcue_spider+(1|skink), data=nbay)
anova(n.bask.lme, n.bask.lme2)
Anova(n.bask.lme2) #main effect of activity
summary(n.bask.lme2)
plot(propbask~rankactivity, nbay) #active skinks bask more, but only skinks from north bay

###############################################
#2.2. Cox proportional hazards tests for latency to emerge from shelter
emerge.surv <- with(df, Surv(emerge, emerged))
summary(emerge.surv)
plot(emerge.surv, xlab= "Time", ylab="Emergence Probability")
emerge.coxme <- coxme(emerge.surv~treatment*pop*activity+svl+firstcue_spider + (1|skink), data=df)
emerge.coxme2 <- coxme(emerge.surv~treatment+pop+activity+svl+firstcue_spider + (1|skink), data=df)
emerge.coxme3 <- coxme(emerge.surv~treatment+pop*activity+svl+firstcue_spider + (1|skink), data=df)
emerge.coxme4 <- coxme(emerge.surv~treatment+activity:pop+svl+firstcue_spider + (1|skink), data=df)
anova(emerge.coxme, emerge.coxme2)
anova(emerge.coxme2, emerge.coxme3) #log likelihood is goodness of fit
anova(emerge.coxme2, emerge.coxme4)
summary(emerge.coxme)
Anova(emerge.coxme)

#make separate model for each population
c.emerge.surv <- with(coffs, Surv(emerge, emerged))
summary(c.emerge.surv)
plot(c.emerge.surv, xlab= "Time", ylab="In Shelter Probability")
c.emerge.coxme <- coxme(c.emerge.surv~treatment*activity+svl+firstcue_spider + (1|skink), data=coffs)
c.emerge.coxme2 <- coxme(c.emerge.surv~treatment+activity+svl+firstcue_spider + (1|skink), data=coffs)
anova(c.emerge.coxme, c.emerge.coxme2)
summary(c.emerge.coxme)
Anova(c.emerge.coxme) #no significant effects

n.emerge.surv <- with(nbay, Surv(emerge, emerged))
summary(n.emerge.surv)
plot(n.emerge.surv, xlab= "Time", ylab="In Shelter Probability")
n.emerge.coxme <- coxme(n.emerge.surv~treatment*activity+svl+firstcue_spider + (1|skink), data=nbay)
n.emerge.coxme2 <- coxme(n.emerge.surv~treatment+activity+svl+firstcue_spider + (1|skink), data=nbay)
anova(n.emerge.coxme, n.emerge.coxme2) #better without interaction
n.emerge.coxme
n.emerge.coxme2
summary(n.emerge.coxme)
Anova(n.emerge.coxme) #main effect of activity and treatment order (spider)

###############################################################
#2.3. Cox proportional hazards tests for foraging speed (latency to catch cricket)
catch.surv <- with(df, Surv(catch, eaten))
summary(catch.surv)
plot(catch.surv, xlab= "Time", ylab="Not Catch Probability")
catch.coxme <- coxme(catch.surv~treatment*pop*activity+svl+firstcue_spider + (1|skink), data=df)
catch.coxme2 <- coxme(catch.surv~treatment+pop+activity+svl+firstcue_spider + (1|skink), data=df)
catch.coxme3 <- coxme(catch.surv~treatment+pop*activity+svl+firstcue_spider + (1|skink), data=df)
anova(catch.coxme, catch.coxme2)
anova(catch.coxme2, catch.coxme3)
summary(catch.coxme)
Anova(catch.coxme) #treatment significant
# Create predator cues life tables and KM plots broken out by treatment
surv.by.pcues.rx <- survfit(Surv(catch,) ~ treatment, data = df)
summary(surv.by.pcues.rx)
# Plot KM 
plot(surv.by.pcues.rx,  xlab = "Time", ylab="survival ", col=c("black", "red", "purple"), lty = 1:2, main="Kaplan-Meier Survival vs. catch cricket",)
# Add legend
legend(1500, .9, c("control","snake", "spider"), lty = 1:2, col=c("black", "red", "purple"))
#a ggplot with risk table
ggsurvplot(surv.by.pcues.rx,
           pval = TRUE, conf.int = TRUE,
           conf.int.style = "ribbon",
           risk.table = TRUE, # Add risk table
           risk.table.col = "strata", # Change risk table color by groups
           linetype = "strata", # Change line type by groups
           surv.median.line = "hv", # Specify median survival
           ggtheme = theme_light(), # Change ggplot2 theme
           legend.labs = 
             c("Control", "Snake","Spider"), 
           palette = c( "#2E9FDF","#2E1FDF", "#E7B800"))

#Experiment 3: simultaneous predator threats
#######################################################################
# 3.1. Cox proportional hazards tests to measure latency to enter the shelter
decision.surv <- with(dfs, Surv(latency.shelter, decision))
decision.cox1<-coxph(decision.surv~population+rankactivity, data=dfs)
decision.cox2<-coxph(decision.surv~population*activity, data=dfs)
anova(decision.cox1, decision.cox2)
AIC(decision.cox1)
AIC(decision.cox2)
Anova(decision.cox2, type = "II", test = "Wald")
summary(decision.cox2)
# Next, we need to check that the assumption of proportionality is not violated.
# The assumption of proportionality is tested by examining the interaction 
#between Schoenfeld residuals and log time (coxph and cox.zph functions, survival package).
time.dep <- coxph(decision.surv~population+activity, data = dfs, method="breslow", na.action=na.exclude)
time.dep.zph <- cox.zph(time.dep, transform = 'log')
time.dep.zph
surv.by.decision <- survfit(Surv(latency.shelter,) ~ population, data = dfs)
summary(surv.by.decision)
#a ggplot with risk table
ggsurvplot(surv.by.decision,
           pval = TRUE, conf.int = TRUE,
           conf.int.style = "ribbon",
           risk.table = TRUE, 
           risk.table.col = "strata", 
           linetype = "strata", 
           surv.median.line = "hv", 
           ggtheme = theme_light(), 
           legend.labs = 
             c("coffs","nbay"), 
           palette = c( "#2E9FDF","#2E1FDF"))
summary(dfs$latency.shelter)

###############################################
#3.2. binomial glm to measure whether the safe or predator-scented shelter was chosen
#make a safe/not safe variable 
dfs$safe<-recode_factor(dfs$initial.condition, z = 0 , y = 1)
#make a 'safe' decision
safe.glm1<-glm(safe~population*activity, family="binomial", data=dfs)
summary(safe.glm1)
Anova(safe.glm1, type = 'II', test = "Wald")
summary(dfs$safe)









